#include <QtGui>

#include "mainwindow.h"
#include "spektrum.h"
#include "edc.h"

Edc edc;
char quelle[256] = "AU_00.VIR";


MainWindow::MainWindow() 
{
    QWidget *w = new QWidget;
	setCentralWidget(w);
    edc.init();
    Spektrum *spektrum = new Spektrum;
	
	QVBoxLayout *buttons = new QVBoxLayout;
	
	QLineEdit *datei = new QLineEdit;	
	buttons->addWidget(datei);	
	
    QPushButton *load = new QPushButton(tr("Laden"));	
	buttons->addWidget(load);	
	connect(load, SIGNAL(clicked()), this, SLOT(slotLoad()));	

	QLabel *werte = new QLabel(tr("Gold auf Spalthebel\n") + 
	    "Hhe: " + QString::number(edc.channels) + "\n" +
		"Breite: " + QString::number(variableG));	
	buttons->addWidget(werte);	
	
    QPushButton *smooth = new QPushButton(tr("Gltten"));	
	buttons->addWidget(smooth);	
	connect(smooth, SIGNAL(clicked()), this, SLOT(slotSmooth()));

    QPushButton *spikes = new QPushButton(tr("Spikes entfernen"));	
	buttons->addWidget(spikes);
	connect(spikes, SIGNAL(clicked()), this, SLOT(slotSpikes()));	

    QPushButton *shirley = new QPushButton(tr("Shirley abziehen"));
	buttons->addWidget(shirley);	
	connect(shirley, SIGNAL(clicked()), this, SLOT(slotShirley()));	
	
	QPushButton *save = new QPushButton(tr("Save"));	
	buttons->addWidget(save);	
	connect(save,    SIGNAL(clicked()), this, SLOT(slotSave()));
	
	QPushButton *quit = new QPushButton(tr("&Quit"));
	buttons->addWidget(quit);	
    connect(quit,    SIGNAL(clicked()), qApp, SLOT(quit()));	
	
// ab hier lschen	
	slider = new QSlider(Qt::Horizontal);
	slider->setRange(5,edc.channels);
	slider->setValue(edc.channels/2);
	buttons->addWidget(slider);
	connect(slider, SIGNAL(valueChanged(int)), spektrum, SLOT(neuerung(int)));
	connect(slider, SIGNAL(valueChanged(int)), this, SIGNAL(valueChanged(int)));	
	
	QLCDNumber *lcd = new QLCDNumber(3);
	lcd->setSegmentStyle(QLCDNumber::Filled);	
	buttons->addWidget(lcd);
	connect(slider, SIGNAL(valueChanged(int)), lcd, SLOT(display(int)));	
//bis hier hin

	buttons->addStretch(1);
	
	connect(this, SIGNAL(updateSpec(int,float,float,float,float,float*)), 
	          spektrum, SLOT(reload(int,float,float,float,float,float*)));	

    createActions();
	createMenus();
    createToolBars();
		connect(slider, SIGNAL(valueChanged(int)), spektrum, SLOT(neuerung(int)));


		
    QGridLayout *mainLayout = new QGridLayout;
	mainLayout->addLayout(buttons,0,0);
	mainLayout->addWidget(spektrum,0,1);
	mainLayout->setColumnStretch(1,1);
	mainLayout->setColumnMinimumWidth(1,200);
	w->setLayout(mainLayout);
		
	setWindowTitle(tr("Auswerten von VIR Daten"));
	setWindowIcon(QIcon(":/images/logo3.png"));
}

void MainWindow::createActions()
{
    newAct = new QAction(QIcon(":/images/new.png"), tr("&New"), this);
    newAct->setShortcut(tr("Ctrl+N"));
    newAct->setStatusTip(tr("Create a new file"));
    connect(newAct, SIGNAL(triggered()), this, SLOT(newFile()));

    openAct = new QAction(QIcon(":/images/open.png"), tr("&Open..."), this);
    openAct->setShortcut(tr("Ctrl+O"));
    openAct->setStatusTip(tr("Open an existing file"));
    connect(openAct, SIGNAL(triggered()), this, SLOT(open()));

    saveAct = new QAction(QIcon(":/images/save.png"), tr("&Save"), this);
    saveAct->setShortcut(tr("Ctrl+S"));
    saveAct->setStatusTip(tr("Save the document to disk"));
    connect(saveAct, SIGNAL(triggered()), this, SLOT(save()));

    saveAsAct = new QAction(tr("Save &As..."), this);
    saveAsAct->setStatusTip(tr("Save the document under a new name"));
    connect(saveAsAct, SIGNAL(triggered()), this, SLOT(saveAs()));

    exitAct = new QAction(QIcon(":/images/exit.png"), tr("E&xit"), this);
    exitAct->setShortcut(tr("Ctrl+Q"));
    exitAct->setStatusTip(tr("Exit the application"));
    connect(exitAct, SIGNAL(triggered()), this, SLOT(close()));

    cutAct = new QAction(QIcon(":/images/cut.png"), tr("Cu&t"), this);
    cutAct->setShortcut(tr("Ctrl+X"));
    cutAct->setStatusTip(tr("Cut the current selection's contents to the "
                                "clipboard"));

    copyAct = new QAction(QIcon(":/images/copy.png"), tr("&Copy"), this);
    copyAct->setShortcut(tr("Ctrl+C"));
    copyAct->setStatusTip(tr("Copy the current selection's contents to the "
                                 "clipboard"));

    pasteAct = new QAction(QIcon(":/images/paste.png"), tr("&Paste"), this);
    pasteAct->setShortcut(tr("Ctrl+V"));
    pasteAct->setStatusTip(tr("Paste the clipboard's contents into the current "
                              "selection"));

    aboutAct = new QAction(tr("&About vir2os"), this);
    aboutAct->setStatusTip(tr("Show the application's About box"));
    connect(aboutAct, SIGNAL(triggered()), this, SLOT(about()));

    aboutQtAct = new QAction(tr("About &Qt"), this);
    aboutQtAct->setStatusTip(tr("Show the Qt library's About box"));
    connect(aboutQtAct, SIGNAL(triggered()), qApp, SLOT(aboutQt()));
    }

void MainWindow::createMenus()
{
        fileMenu = menuBar()->addMenu(tr("&File"));
        fileMenu->addAction(newAct);
        fileMenu->addAction(openAct);
        fileMenu->addAction(saveAct);
        fileMenu->addAction(saveAsAct);
        fileMenu->addSeparator();
        fileMenu->addAction(exitAct);

        editMenu = menuBar()->addMenu(tr("&Edit"));
        editMenu->addAction(cutAct);
        editMenu->addAction(copyAct);
        editMenu->addAction(pasteAct);

        menuBar()->addSeparator();

        helpMenu = menuBar()->addMenu(tr("&Help"));
        helpMenu->addAction(aboutAct);
        helpMenu->addAction(aboutQtAct);
}

void MainWindow::createToolBars()
{
        fileToolBar = addToolBar(tr("File"));
        fileToolBar->addAction(newAct);
        fileToolBar->addAction(openAct);
        fileToolBar->addAction(saveAct);

        editToolBar = addToolBar(tr("Edit"));
        editToolBar->addAction(cutAct);
        editToolBar->addAction(copyAct);
        editToolBar->addAction(pasteAct);
}	
	
void MainWindow::slotLoad()
{
    edc.load(quelle);
	submit();
}
	
void MainWindow::slotSmooth()
{
    edc.smooth();
	submit();
}
	
void MainWindow::slotSpikes() // Spikes entfernen
{
    edc.spikes();
	submit();
}	
	
void MainWindow::slotShirley() // Shirleyuntergrund entfernen
{
    edc.shirley();
	submit();
}	
	
void MainWindow::slotSave()
{
    edc.init();
	submit();
}
bool MainWindow::saveAs()
{
return true;
}
void MainWindow::documentWasModified() {  }
void MainWindow::about()
{
    QMessageBox::about(this, tr("ber vir2os"),
        tr("Diese <b>Anwendung</b> wurde von Matthias Kreier geschrieben "
           "und unterliegt der GNU GPL. Es dient dazu, die Messdaten der "
           "ARPES (Angle Resoved Photo Emission Spectroscopy) Anlage  "
           "WESPHOA I (Winkelaufgelstes ElektronenSPektrometer HOher "
           "Auflsung) darzustellen, zu manipulieren und zu speichern."));
    }
bool MainWindow::save() 
{
  return true;
}

void MainWindow::open()
{
    if (maybeSave()) {
        QString fileName = QFileDialog::getOpenFileName(this);
        if (!fileName.isEmpty())
            loadFile(fileName);
    }
}

    bool MainWindow::maybeSave()
    {
        int ret = QMessageBox::warning(this, tr("Application"),
                     tr("The document has been modified.\n"
                        "Do you want to save your changes?"),
                QMessageBox::Yes | QMessageBox::Default,
                QMessageBox::No,
                QMessageBox::Cancel | QMessageBox::Escape);
    if (ret == QMessageBox::Yes)
        return save();
    else if (ret == QMessageBox::Cancel)
        return false;
    return true;
}

void MainWindow::loadFile(const QString &fileName)
{
    for(int i = 0; i < fileName.size(); i++)
    {
       quelle[i] = fileName.toStdString()[i];
    } 
    edc.load(quelle);
	submit();
}

void MainWindow::newFile() {  }

	
void MainWindow::submit()
{
    float transfer[edc.channels];
	for(int i=0;i<edc.channels;i++){transfer[i]=edc.data[1][i];}
	emit updateSpec(edc.channels,edc.Emin,edc.Emax,edc.yMin,edc.yMax,transfer);
}
	
